(**************************************************************************)
(*                                                                        *)
(*  This file is part of Frama-C.                                         *)
(*                                                                        *)
(*  Copyright (C) 2007-2015                                               *)
(*    CEA (Commissariat à l'énergie atomique et aux énergies              *)
(*         alternatives)                                                  *)
(*                                                                        *)
(*  you can redistribute it and/or modify it under the terms of the GNU   *)
(*  Lesser General Public License as published by the Free Software       *)
(*  Foundation, version 2.1.                                              *)
(*                                                                        *)
(*  It is distributed in the hope that it will be useful,                 *)
(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *)
(*  GNU Lesser General Public License for more details.                   *)
(*                                                                        *)
(*  See the GNU Lesser General Public License version 2.1                 *)
(*  for more details (enclosed in the file licenses/LGPLv2.1).            *)
(*                                                                        *)
(**************************************************************************)

let version = "Sodium-20150201"
let date = "Wed Sep  2 12:37:12 UTC 2015"

let is_gui = ref false

let ocamlc = "ocamlc.opt"
let ocamlopt = "ocamlopt.opt"

let datadir = try Sys.getenv "FRAMAC_SHARE" with Not_found -> "/usr/share/frama-c"
let () = Filepath.add_symbolic_dir "FRAMAC_SHARE" datadir
let libdir = try Sys.getenv "FRAMAC_LIB" with Not_found -> "/usr/lib64/frama-c"
let () = Filepath.add_symbolic_dir "FRAMAC_LIB" libdir
let plugin_dir =
  try Sys.getenv "FRAMAC_PLUGIN"
  with Not_found ->
    try (Sys.getenv "FRAMAC_LIB") ^ "/plugins"
    with Not_found ->
      let myself = Filename.basename Sys.executable_name in
      let myself = if Filename.check_suffix myself (".opt" ^ "")
        then Filename.chop_suffix myself (".opt" ^ "")
	else myself
      in
      let myself =
	if Filename.check_suffix myself (".byte" ^ "")
	then Filename.chop_suffix myself (".byte" ^ "")
	else myself
      in
      if myself = "toplevel" || myself = "viewer" then
	"/builddir/build/BUILD/frama-c-Sodium-20150201/lib/plugins"
      else "/usr/lib64/frama-c/plugins"
let () = Filepath.add_symbolic_dir "FRAMAC_PLUGIN" plugin_dir

let preprocessor =
  try Sys.getenv "CPP" with Not_found -> "gcc -E -C -I."

let preprocessor_is_gnu_like =
  try ignore (Sys.getenv "CPP"); false with Not_found -> true

let preprocessor_keep_comments =
  try (ignore (Sys.getenv "CPP"); true)
  with Not_found -> true

let static_plugins = ["Metrics";  "Syntactic_callgraph";  "Value";  "Occurrence";  "RteGen";  "From";  "Users";  "Constant_Propagation";  "Postdominators";  "Inout";  "Semantic_callgraph";  "Impact";  "Pdg";  "Scope";  "Sparecode";  "Slicing"; ]
let static_gui_plugins = ["Metrics";  "Syntactic_callgraph";  "Value";  "Occurrence";  "From";  "Impact";  "Scope";  "Slicing"; ]

let compilation_unit_names = ["frama_c_init";  "unmarshal";  "unmarshal_nums";  "sysutil";  "unz";  "dynlink_common_interface";  "structural_descr";  "type";  "descr";  "FCSet";  "FCMap";  "FCHashtbl";  "extlib";  "pretty_utils";  "hook";  "bag";  "indexer";  "vector";  "bitvector";  "qstack";  "integer";  "filepath";  "config";  "gui_init";  "log";  "cmdline";  "project_skeleton";  "datatype";  "journal";  "state";  "state_dependency_graph";  "state_topological";  "state_selection";  "project";  "state_builder";  "binary_cache";  "hptmap";  "hptset";  "cil_datatype";  "typed_parameter";  "dynamic";  "parameter_category";  "parameter_customize";  "parameter_state";  "parameter_builder";  "plugin";  "kernel";  "emitter";  "floating_point";  "rangemap";  "printer_builder";  "cilmsg";  "alpha";  "cilconfig";  "cil_state_builder";  "utf8_logic";  "machdeps";  "cil_const";  "logic_env";  "escape";  "logic_const";  "cil";  "cil_printer";  "cil_descriptive_printer";  "errorloc";  "cabs";  "cabs_debug";  "cabshelper";  "logic_utils";  "logic_builtin";  "logic_print";  "logic_parser";  "logic_lexer";  "lexerhack";  "mergecil";  "rmtmps";  "logic_typing";  "cprint";  "cabsvisit";  "cabs2cil";  "clexer";  "cparser";  "logic_preprocess";  "frontc";  "callgraph";  "dataflow";  "oneret";  "cfg";  "ast_info";  "ast";  "globals";  "kernel_function";  "property";  "property_status";  "annotations";  "printer";  "stmts_graph";  "ordered_stmt";  "dataflows";  "dataflow2";  "dominators";  "description";  "statuses_by_call";  "alarms";  "messages";  "abstract_interp";  "int_Base";  "unicode";  "service_graph";  "ival";  "bit_utils";  "base";  "origin";  "map_Lattice";  "trace";  "value_messages";  "cilE";  "tr_offset";  "offsetmap";  "int_Intervals";  "locations";  "precise_locs";  "lmap";  "lmap_bitwise";  "function_Froms";  "cvalue";  "widen_type";  "visitor";  "clone";  "loop";  "inout_type";  "pdgIndex";  "pdgTypes";  "pdgMarks";  "slicingInternals";  "slicingTypes";  "value_types";  "db";  "command";  "task";  "file";  "exn_flow";  "translate_lightweight";  "unroll_loops";  "filter";  "special_hooks";  "logic_interp";  "infer_annotations";  "allocates";  "Metrics";  "Syntactic_callgraph";  "Value";  "Occurrence";  "RteGen";  "From";  "Users";  "Constant_Propagation";  "Postdominators";  "Inout";  "Semantic_callgraph";  "Impact";  "Pdg";  "Scope";  "Sparecode";  "Slicing";  "boot";  "dgraph";  "gui_parameters";  "gtk_helper";  "gtk_form";  "toolbox";  "source_viewer";  "pretty_source";  "source_manager";  "book_manager";  "warning_manager";  "filetree";  "launcher";  "menu_manager";  "history";  "design";  "analyses_manager";  "file_manager";  "project_manager";  "debug_manager";  "help_manager";  "property_navigator";  "Metrics";  "Syntactic_callgraph";  "Value";  "Occurrence";  "From";  "Impact";  "Scope";  "Slicing"; ]

let dot = Some "dot"
